@@ -41,6 +41,7 @@ from mypy_boto3_ram.type_defs import (
     ListPermissionsResponseTypeDef,
     ListPrincipalsResponseTypeDef,
     ListResourceSharePermissionsResponseTypeDef,
+    ListResourceTypesResponseTypeDef,
     ListResourcesResponseTypeDef,
     PromoteResourceShareCreatedFromPolicyResponseTypeDef,
     RejectResourceShareInvitationResponseTypeDef,
@@ -85,7 +86,7 @@ class Exceptions:
 
 class RAMClient:
     """
-    [RAM.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client)
+    [RAM.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client)
     """
 
     exceptions: Exceptions
@@ -94,7 +95,7 @@ class RAMClient:
         self, resourceShareInvitationArn: str, clientToken: str = None
     ) -> AcceptResourceShareInvitationResponseTypeDef:
         """
-        [Client.accept_resource_share_invitation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
+        [Client.accept_resource_share_invitation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
         """
 
     def associate_resource_share(
@@ -105,7 +106,7 @@ class RAMClient:
         clientToken: str = None,
     ) -> AssociateResourceShareResponseTypeDef:
         """
-        [Client.associate_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.associate_resource_share)
+        [Client.associate_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.associate_resource_share)
         """
 
     def associate_resource_share_permission(
@@ -116,12 +117,12 @@ class RAMClient:
         clientToken: str = None,
     ) -> AssociateResourceSharePermissionResponseTypeDef:
         """
-        [Client.associate_resource_share_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
+        [Client.associate_resource_share_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.can_paginate)
         """
 
     def create_resource_share(
@@ -135,14 +136,14 @@ class RAMClient:
         permissionArns: List[str] = None,
     ) -> CreateResourceShareResponseTypeDef:
         """
-        [Client.create_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.create_resource_share)
+        [Client.create_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.create_resource_share)
         """
 
     def delete_resource_share(
         self, resourceShareArn: str, clientToken: str = None
     ) -> DeleteResourceShareResponseTypeDef:
         """
-        [Client.delete_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.delete_resource_share)
+        [Client.delete_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.delete_resource_share)
         """
 
     def disassociate_resource_share(
@@ -153,21 +154,21 @@ class RAMClient:
         clientToken: str = None,
     ) -> DisassociateResourceShareResponseTypeDef:
         """
-        [Client.disassociate_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.disassociate_resource_share)
+        [Client.disassociate_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.disassociate_resource_share)
         """
 
     def disassociate_resource_share_permission(
         self, resourceShareArn: str, permissionArn: str, clientToken: str = None
     ) -> DisassociateResourceSharePermissionResponseTypeDef:
         """
-        [Client.disassociate_resource_share_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
+        [Client.disassociate_resource_share_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
         """
 
     def enable_sharing_with_aws_organization(
         self,
     ) -> EnableSharingWithAwsOrganizationResponseTypeDef:
         """
-        [Client.enable_sharing_with_aws_organization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
+        [Client.enable_sharing_with_aws_organization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
         """
 
     def generate_presigned_url(
@@ -178,14 +179,14 @@ class RAMClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.generate_presigned_url)
         """
 
     def get_permission(
         self, permissionArn: str, permissionVersion: int = None
     ) -> GetPermissionResponseTypeDef:
         """
-        [Client.get_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.get_permission)
+        [Client.get_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.get_permission)
         """
 
     def get_resource_policies(
@@ -196,7 +197,7 @@ class RAMClient:
         maxResults: int = None,
     ) -> GetResourcePoliciesResponseTypeDef:
         """
-        [Client.get_resource_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.get_resource_policies)
+        [Client.get_resource_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.get_resource_policies)
         """
 
     def get_resource_share_associations(
@@ -212,7 +213,7 @@ class RAMClient:
         maxResults: int = None,
     ) -> GetResourceShareAssociationsResponseTypeDef:
         """
-        [Client.get_resource_share_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.get_resource_share_associations)
+        [Client.get_resource_share_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.get_resource_share_associations)
         """
 
     def get_resource_share_invitations(
@@ -223,7 +224,7 @@ class RAMClient:
         maxResults: int = None,
     ) -> GetResourceShareInvitationsResponseTypeDef:
         """
-        [Client.get_resource_share_invitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
+        [Client.get_resource_share_invitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
         """
 
     def get_resource_shares(
@@ -237,21 +238,21 @@ class RAMClient:
         maxResults: int = None,
     ) -> GetResourceSharesResponseTypeDef:
         """
-        [Client.get_resource_shares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.get_resource_shares)
+        [Client.get_resource_shares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.get_resource_shares)
         """
 
     def list_pending_invitation_resources(
         self, resourceShareInvitationArn: str, nextToken: str = None, maxResults: int = None
     ) -> ListPendingInvitationResourcesResponseTypeDef:
         """
-        [Client.list_pending_invitation_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
+        [Client.list_pending_invitation_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
         """
 
     def list_permissions(
         self, resourceType: str = None, nextToken: str = None, maxResults: int = None
     ) -> ListPermissionsResponseTypeDef:
         """
-        [Client.list_permissions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.list_permissions)
+        [Client.list_permissions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.list_permissions)
         """
 
     def list_principals(
@@ -265,14 +266,21 @@ class RAMClient:
         maxResults: int = None,
     ) -> ListPrincipalsResponseTypeDef:
         """
-        [Client.list_principals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.list_principals)
+        [Client.list_principals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.list_principals)
         """
 
     def list_resource_share_permissions(
         self, resourceShareArn: str, nextToken: str = None, maxResults: int = None
     ) -> ListResourceSharePermissionsResponseTypeDef:
         """
-        [Client.list_resource_share_permissions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
+        [Client.list_resource_share_permissions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
+        """
+
+    def list_resource_types(
+        self, nextToken: str = None, maxResults: int = None
+    ) -> ListResourceTypesResponseTypeDef:
+        """
+        [Client.list_resource_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.list_resource_types)
         """
 
     def list_resources(
@@ -286,31 +294,31 @@ class RAMClient:
         maxResults: int = None,
     ) -> ListResourcesResponseTypeDef:
         """
-        [Client.list_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.list_resources)
+        [Client.list_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.list_resources)
         """
 
     def promote_resource_share_created_from_policy(
         self, resourceShareArn: str
     ) -> PromoteResourceShareCreatedFromPolicyResponseTypeDef:
         """
-        [Client.promote_resource_share_created_from_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
+        [Client.promote_resource_share_created_from_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
         """
 
     def reject_resource_share_invitation(
         self, resourceShareInvitationArn: str, clientToken: str = None
     ) -> RejectResourceShareInvitationResponseTypeDef:
         """
-        [Client.reject_resource_share_invitation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
+        [Client.reject_resource_share_invitation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
         """
 
     def tag_resource(self, resourceShareArn: str, tags: List[TagTypeDef]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.tag_resource)
         """
 
     def untag_resource(self, resourceShareArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.untag_resource)
         """
 
     def update_resource_share(
@@ -321,7 +329,7 @@ class RAMClient:
         clientToken: str = None,
     ) -> UpdateResourceShareResponseTypeDef:
         """
-        [Client.update_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Client.update_resource_share)
+        [Client.update_resource_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Client.update_resource_share)
         """
 
     @overload
@@ -329,7 +337,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_policies"]
     ) -> GetResourcePoliciesPaginator:
         """
-        [Paginator.GetResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+        [Paginator.GetResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
         """
 
     @overload
@@ -337,7 +345,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_share_associations"]
     ) -> GetResourceShareAssociationsPaginator:
         """
-        [Paginator.GetResourceShareAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+        [Paginator.GetResourceShareAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
         """
 
     @overload
@@ -345,7 +353,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_share_invitations"]
     ) -> GetResourceShareInvitationsPaginator:
         """
-        [Paginator.GetResourceShareInvitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+        [Paginator.GetResourceShareInvitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
         """
 
     @overload
@@ -353,17 +361,17 @@ class RAMClient:
         self, operation_name: Literal["get_resource_shares"]
     ) -> GetResourceSharesPaginator:
         """
-        [Paginator.GetResourceShares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+        [Paginator.GetResourceShares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Paginator.GetResourceShares)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_principals"]) -> ListPrincipalsPaginator:
         """
-        [Paginator.ListPrincipals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+        [Paginator.ListPrincipals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Paginator.ListPrincipals)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resources"]) -> ListResourcesPaginator:
         """
-        [Paginator.ListResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/ram.html#RAM.Paginator.ListResources)
+        [Paginator.ListResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/ram.html#RAM.Paginator.ListResources)
         """
