@@ -47,6 +47,8 @@ __all__ = (
     "PrincipalTypeDef",
     "ListPrincipalsResponseTypeDef",
     "ListResourceSharePermissionsResponseTypeDef",
+    "ServiceNameAndResourceTypeTypeDef",
+    "ListResourceTypesResponseTypeDef",
     "ListResourcesResponseTypeDef",
     "PaginatorConfigTypeDef",
     "PromoteResourceShareCreatedFromPolicyResponseTypeDef",
@@ -260,6 +262,16 @@ ListResourceSharePermissionsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ServiceNameAndResourceTypeTypeDef = TypedDict(
+    "ServiceNameAndResourceTypeTypeDef", {"resourceType": str, "serviceName": str}, total=False
+)
+
+ListResourceTypesResponseTypeDef = TypedDict(
+    "ListResourceTypesResponseTypeDef",
+    {"resourceTypes": List[ServiceNameAndResourceTypeTypeDef], "nextToken": str},
+    total=False,
+)
+
 ListResourcesResponseTypeDef = TypedDict(
     "ListResourcesResponseTypeDef",
     {"resources": List[ResourceTypeDef], "nextToken": str},
